@@ -1,5 +1,5 @@
 # IPC::Locker.pm -- distributed lock handler
-# $Id: Locker.pm 58 2007-01-24 20:23:37Z wsnyder $
+# $Id: Locker.pm 64 2007-04-03 15:40:55Z wsnyder $
 # Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
@@ -165,7 +165,7 @@ first argument is self.  Defaults to a croak message.
 The maximum time in seconds that the lock may be held before being forced
 open, passed to the server when the lock is created.  Thus if the requester
 dies, the lock will be released after that amount of time.  Zero disables
-the timeout.  Defaults to 10 minutes.
+the timeout.  Defaults to 30 minutes.
 
 =item user
 
@@ -243,7 +243,7 @@ use Carp;
 # Other configurable settings.
 $Debug = 0;
 
-$VERSION = '1.461';
+$VERSION = '1.462';
 
 ######################################################################
 #### Useful Globals
@@ -424,7 +424,7 @@ sub _request {
 	       ."block ".($self->{block}||0)."\n"
 	       ."timeout ".($self->{timeout}||0)."\n");
     $req.=    ("autounlock ".($self->{autounlock}||0)."\n"
-	       ."pid $$\n"
+	       ."pid ".($self->{pid}||$$)."\n"
 	       ."hostname ".($self->{hostname})."\n"
 	       ) if $self->{autounlock};
     $req.=    ("$cmd\n");
